<?php
/**
 * Hungarian language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Ziegler Gábor <gziegler@freemail.hu>
 * @author Sandor TIHANYI <stihanyi+dw@gmail.com>
 * @author Siaynoq Mage <siaynoqmage@gmail.com>
 * @author schilling.janos@gmail.com
 * @author Szabó Dávid <szabo.david@gyumolcstarhely.hu>
 * @author Sándor TIHANYI <stihanyi+dw@gmail.com>
 * @author David Szabo <szabo.david@gyumolcstarhely.hu>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '„';
$lang['doublequoteclosing']    = '”';
$lang['singlequoteopening']    = '‚';
$lang['singlequoteclosing']    = '’';
$lang['apostrophe']            = '’';
$lang['btn_edit']              = 'Oldal szerkesztése';
$lang['btn_source']            = 'Oldalforrás megtekintése';
$lang['btn_show']              = 'Oldal megtekintése';
$lang['btn_create']            = 'Oldal létrehozása';
$lang['btn_search']            = 'Keresés';
$lang['btn_save']              = 'Mentés';
$lang['btn_preview']           = 'Előnézet';
$lang['btn_top']               = 'Vissza a tetejére';
$lang['btn_newer']             = '<< Újabb változat';
$lang['btn_older']             = 'Régebbi változat >>';
$lang['btn_revs']              = 'Korábbi változatok';
$lang['btn_recent']            = 'Legfrissebb változások';
$lang['btn_upload']            = 'Feltöltés';
$lang['btn_cancel']            = 'Mégsem';
$lang['btn_index']             = 'Áttekintő';
$lang['btn_secedit']           = 'Szerkesztés';
$lang['btn_login']             = 'Bejelentkezés';
$lang['btn_logout']            = 'Kijelentkezés';
$lang['btn_admin']             = 'Admin';
$lang['btn_update']            = 'Frissítés';
$lang['btn_delete']            = 'Törlés';
$lang['btn_back']              = 'Vissza';
$lang['btn_backlink']          = 'Hivatkozások';
$lang['btn_backtomedia']       = 'Vissza a médiafájlok kezeléséhez';
$lang['btn_subscribe']         = 'Oldalváltozások-hírlevél feliratkozás';
$lang['btn_profile']           = 'Személyes beállítások';
$lang['btn_reset']             = 'Alaphelyzet';
$lang['btn_draft']             = 'Piszkozat szerkesztése';
$lang['btn_recover']           = 'Piszkozat folytatása';
$lang['btn_draftdel']          = 'Piszkozat törlése';
$lang['btn_revert']            = 'Helyreállítás';
$lang['btn_register']          = 'Regisztráció';
$lang['loggedinas']            = 'Belépett felhasználó: ';
$lang['user']                  = 'Azonosító';
$lang['pass']                  = 'Jelszó';
$lang['newpass']               = 'Új jelszó';
$lang['oldpass']               = 'Régi jelszó';
$lang['passchk']               = 'még egyszer';
$lang['remember']              = 'Emlékezz rám';
$lang['fullname']              = 'Teljes név';
$lang['email']                 = 'E-Mail';
$lang['profile']               = 'Személyes beállítások';
$lang['badlogin']              = 'Sajnáljuk, az azonosító, vagy a jelszó nem jó.';
$lang['minoredit']             = 'Apróbb változások';
$lang['draftdate']             = 'Piszkozat elmentve:';
$lang['nosecedit']             = 'Időközben megváltozott az oldal, emiatt a szakasz nem friss. Töltse újra az egész oldalt!';
$lang['regmissing']            = 'Sajnáljuk, az összes mezőt ki kell töltened.';
$lang['reguexists']            = 'Sajnáljuk, ilyen azonosítójú felhasználónk már van.';
$lang['regsuccess']            = 'A felhasználói azonosítót létrehoztuk. A jelszót postáztuk.';
$lang['regsuccess2']           = 'A felhasználói azonosítót létrehoztuk.';
$lang['regmailfail']           = 'Úgy tűnik hiba történt a jelszó postázása során. Kérjük lépj kapcsolatba a Wiki-gazdával!!';
$lang['regbadmail']            = 'A megadott e-mail cím érvénytelennek tűnik. Ha úgy gondolod ez hiba, lépj kapcsolatba Wiki-gazdával!';
$lang['regbadpass']            = 'A két megadott jelszó nem egyezik, próbáld újra!';
$lang['regpwmail']             = 'A DokuWiki jelszavad';
$lang['reghere']               = 'Még nincs azonosítód? Itt kérhetsz';
$lang['profna']                = 'Ez a wiki nem támogatja a személyes beállítások módosítását.';
$lang['profnochange']          = 'Nem történt változás.';
$lang['profnoempty']           = 'A név és e-mail mező nem maradhat üresen!';
$lang['profchanged']           = 'A személyes beállítások változtatása megtörtént.';
$lang['pwdforget']             = 'Elfelejtetted a jelszavad? Itt kérhetsz újat';
$lang['resendna']              = 'Ez a wiki nem támogatja a jelszó újraküldést.';
$lang['resendpwdmissing']      = 'Sajnáljuk, az összes mezőt ki kell töltened.';
$lang['resendpwdnouser']       = 'Sajnáljuk, ilyen azonosítójú felhasználónk nem létezik.';
$lang['resendpwdbadauth']      = 'Sajnáljuk, ez a megerősítő kód nem helyes. Biztos, hogy a teljes megerősítés linket beírtad pontosan?';
$lang['resendpwdconfirm']      = 'A megerősítés linket e-mailben elküldtük.';
$lang['resendpwdsuccess']      = 'Az új jelszavadat elküldtük e-mailben.';
$lang['license']               = 'Hacsak máshol nincs egyéb rendelkezés, ezen wiki tartalma a következő licenc alatt érhető el:';
$lang['licenseok']             = 'Megjegyzés: az oldal szerkesztésével elfogadja, hogy a tartalom a következő licenc alatt lesz elérhető:';
$lang['searchmedia']           = 'Keresett fájl neve:';
$lang['searchmedia_in']        = 'Keresés a következőben: %s';
$lang['txt_upload']            = 'Válaszd ki a feltöltendő fájlt';
$lang['txt_filename']          = 'feltöltési név (elhagyható)';
$lang['txt_overwrt']           = 'Létező fájl felülírása';
$lang['lockedby']              = 'Jelenleg zárolta:';
$lang['lockexpire']            = 'A zárolás lejár:';
$lang['js']['willexpire']            = 'Az oldalszerkesztési zárolásod körülbelül egy percen belül lejár.\nAz ütközések elkerülése végett használd az előnézet gombot a zárolási időzítés frissítéséhez.';
$lang['js']['notsavedyet']     = 'Elmentetlen változások vannak, amelyek el fognak veszni.
Tényleg ezt akarod?';
$lang['js']['searchmedia']     = 'Fájlok keresése';
$lang['js']['keepopen']        = 'Tartsd nyitva ezt az ablakot a kijelöléshez!';
$lang['js']['hidedetails']     = 'Részletek elrejtése';
$lang['js']['mediatitle']      = 'Link beállítások';
$lang['js']['mediadisplay']    = 'Link típusa';
$lang['js']['mediaalign']      = 'Igazítás';
$lang['js']['mediasize']       = 'Képméret';
$lang['js']['mediatarget']     = 'Link';
$lang['js']['mediaclose']      = 'Bezárás';
$lang['js']['mediainsert']     = 'Beillesztés';
$lang['js']['mediadisplayimg'] = 'Kép megtekintése.';
$lang['js']['mediadisplaylnk'] = 'Link megtekintése.';
$lang['js']['mediasmall']      = 'Kisebb méret';
$lang['js']['mediamedium']     = 'Közepes méret';
$lang['js']['medialarge']      = 'Nagyobb méret';
$lang['js']['mediaoriginal']   = 'Eredeti';
$lang['js']['medialnk']        = 'Link a részletekre';
$lang['js']['mediadirect']     = 'Közvetlen link az eredetire';
$lang['js']['medianolnk']      = 'Nincsen link';
$lang['js']['medianolink']     = 'Ne linkelje a képet';
$lang['js']['medialeft']       = 'Kép igazítása balra.';
$lang['js']['mediaright']      = 'Kép igazítása jobbra.';
$lang['js']['mediacenter']     = 'Kép igazítása középre.';
$lang['js']['medianoalign']    = 'Nem legyen igazítás.';
$lang['js']['nosmblinks']      = 'A Windows megosztott könyvtárak kereszthivatkozása csak  Microsoft Internet Explorerben működik közvetlenül.
A hivatkozást másolni és beszúrni ettől fügetlenül mndig tudod.';
$lang['js']['linkwiz']         = 'Hivatkozás varázsló';
$lang['js']['linkto']          = 'Hivatkozás erre:';
$lang['js']['del_confirm']     = 'Valóban törölni akarod a kiválasztott elem(ek)et?';
$lang['rssfailed']             = 'Hiba történt ennek a betöltésekor: ';
$lang['nothingfound']          = 'Semmit sem találtam.';
$lang['mediaselect']           = 'Médiafájl kiválasztása';
$lang['fileupload']            = 'Médiafájl feltöltése';
$lang['uploadsucc']            = 'A feltöltés sikerült';
$lang['uploadfail']            = 'A feltöltés nem sikerült. Talán rosszak a jogosultságok?';
$lang['uploadwrong']           = 'A feltöltés megtagadva. Ez a fájl kiterjesztés tiltott.';
$lang['uploadexist']           = 'A fájl már létezik, nem történt semmi.';
$lang['uploadbadcontent']      = 'A feltöltött tartalom nem egyezik a %s fájl kiterjesztéssel.';
$lang['uploadspam']            = 'A feltöltést visszautasítottuk spam-gyanú miatt.';
$lang['uploadxss']             = 'A feltöltést visszautasítottuk, mert lehetséges, hogy kártékony kódot tartalmaz.';
$lang['uploadsize']            = 'A feltöltött fájl túl nagy. (max. %s)';
$lang['deletesucc']            = 'A "%s" fájlt töröltük.';
$lang['deletefail']            = 'A "%s" fájl nem törölhető. - Ellenőrizd a jogosultságokat!';
$lang['mediainuse']            = 'A "%s" fájl nem törlődött - még használat alatt van.';
$lang['namespaces']            = 'Névtér';
$lang['mediafiles']            = 'Elérhető fájlok itt:';
$lang['accessdenied']          = 'Nincsen jogod az oldal megtekintésére.';
$lang['mediausage']            = 'A következő formában hivatkozhatsz erre az állományra:';
$lang['mediaview']             = 'Eredeti állomány megtekintése';
$lang['mediaroot']             = 'kiindulási hely';
$lang['mediaupload']           = 'Itt tölthetsz fel állományt az aktuális névtérbe. Al-névtér létrehozásához a "Feltöltési név" mezőben kell kettősponttal elválasztva megadnod azt.';
$lang['mediaextchange']        = 'Az állomány kiterjesztése erről: .%s erre: .%s változott!';
$lang['reference']             = 'Hivatkozások';
$lang['ref_inuse']             = 'A fájl nem törölhető, mert a következő oldalakon használják:';
$lang['ref_hidden']            = 'Van néhány hivatkozás az oldalakon, amelyekhez nincs olvasási jogosultságod';
$lang['hits']                  = 'Találatok';
$lang['quickhits']             = 'Illeszkedő oldalnevek';
$lang['toc']                   = 'Tartalomjegyzék';
$lang['current']               = 'aktuális';
$lang['yours']                 = 'A te változatod';
$lang['diff']                  = 'a különbségeket mutatja az aktuális változathoz képest';
$lang['diff2']                 = 'a különbségeket mutatja a kiválasztott változatok között';
$lang['difflink']              = 'Összehasonlító nézet linkje';
$lang['diff_type']             = 'Összehasonlítás módja:';
$lang['diff_inline']           = 'Sorok között';
$lang['diff_side']             = 'Kétoldalas';
$lang['line']                  = 'sorszám';
$lang['breadcrumb']            = 'Nyomvonal';
$lang['youarehere']            = 'Itt vagy';
$lang['lastmod']               = 'Utolsó módosítás';
$lang['by']                    = 'szerkesztette:';
$lang['deleted']               = 'eltávolítva';
$lang['created']               = 'létrehozva';
$lang['restored']              = 'az előző változat helyreállítva (%s)';
$lang['external_edit']         = 'külső szerkesztés';
$lang['summary']               = 'A változások összefoglalása';
$lang['noflash']               = 'Ennek a tartalomnak a megtekintéséhez <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> szükséges.';
$lang['download']              = 'Kódrészlet letöltése';
$lang['mail_newpage']          = 'új oldal jött létre:';
$lang['mail_changed']          = 'oldal megváltozott:';
$lang['mail_subscribe_list']   = 'oldalak megváltoztak ebben a névtérben:';
$lang['mail_new_user']         = 'Új felhasználó:';
$lang['mail_upload']           = 'állományt töltöttek fel:';
$lang['qb_bold']               = 'Félkövér szöveg';
$lang['qb_italic']             = 'Dőlt szöveg';
$lang['qb_underl']             = 'Aláhúzott szöveg';
$lang['qb_code']               = 'Forráskód szöveg';
$lang['qb_strike']             = 'Áthúzott szöveg';
$lang['qb_h1']                 = '1. szintű címsor';
$lang['qb_h2']                 = '2. szintű címsor';
$lang['qb_h3']                 = '3. szintű címsor';
$lang['qb_h4']                 = '4. szintű címsor';
$lang['qb_h5']                 = '5. szintű címsor';
$lang['qb_h']                  = 'Címsor';
$lang['qb_hs']                 = 'Címsor kiválasztása';
$lang['qb_hplus']              = 'Nagyobb címsor';
$lang['qb_hminus']             = 'Kisebb címsor';
$lang['qb_hequal']             = 'Azonos szintű címsor';
$lang['qb_link']               = 'Belső hivatkozás';
$lang['qb_extlink']            = 'Külső hivatkozás';
$lang['qb_hr']                 = 'Vízszintes elválasztó vonal';
$lang['qb_ol']                 = 'Sorszámozott lista elem';
$lang['qb_ul']                 = 'Felsorolás lista elem';
$lang['qb_media']              = 'Képek és más fájlok hozzáadása';
$lang['qb_sig']                = 'Aláírás beszúrása';
$lang['qb_smileys']            = 'Szmájlik';
$lang['qb_chars']              = 'Speciális karakterek';
$lang['upperns']               = 'Ugrás a szülő névtérhez';
$lang['admin_register']        = 'Új felhasználó';
$lang['metaedit']              = 'Meta-adatok szerkesztése';
$lang['metasaveerr']           = 'A meta-adatok írása meghiúsult ';
$lang['metasaveok']            = 'Meta-adatok elmentve';
$lang['img_backto']            = 'Vissza';
$lang['img_title']             = 'Cím';
$lang['img_caption']           = 'Képaláírás';
$lang['img_date']              = 'Dátum';
$lang['img_fname']             = 'Fájlnév';
$lang['img_fsize']             = 'Méret';
$lang['img_artist']            = 'Készítette';
$lang['img_copyr']             = 'Copyright';
$lang['img_format']            = 'Formátum';
$lang['img_camera']            = 'Fényképező típusa';
$lang['img_keywords']          = 'Kulcsszavak';
$lang['subscr_subscribe_success'] = '%s hozzáadva az értesítési listához: %s';
$lang['subscr_subscribe_error'] = 'Hiba történt %s hozzáadásakor az értesítési listához: %s';
$lang['subscr_subscribe_noaddress'] = 'Nincsen e-mail cím megadva az adataidnál, így a rendszer nem tudott hozzáadni az értesítési listához';
$lang['subscr_unsubscribe_success'] = '%s eltávolítva az értesítési listából: %s';
$lang['subscr_unsubscribe_error'] = 'Hiba történt %s eltávolításakor az értesítési listából: %s';
$lang['subscr_already_subscribed'] = '%s már feliratkozott erre: %s';
$lang['subscr_not_subscribed'] = '%s nincsen feliratkozva erre: %s';
$lang['subscr_m_not_subscribed'] = 'Jelenleg nem vagy feliratkozva erre az oldalra vagy névtérre';
$lang['subscr_m_new_header']   = 'Feliratkozás hozzáadása';
$lang['subscr_m_current_header'] = 'Feliratkozások';
$lang['subscr_m_unsubscribe']  = 'Leiratkozás';
$lang['subscr_m_subscribe']    = 'Feliratkozás';
$lang['subscr_m_receive']      = 'Küldj';
$lang['subscr_style_every']    = 'e-mailt minden változásról';
$lang['subscr_style_digest']   = 'összefoglaló e-mailt oldalanként (minden %.2f nap)';
$lang['subscr_style_list']     = 'egy listát a módosított oldalakról a legutóbbi e-mail óta (minden %.2f nap)';
$lang['authmodfailed']         = 'Hibás felhasználó-aznosítási módszer van beállítva. Légy szíves értesítsd a Wiki-gazdát!';
$lang['authtempfail']          = 'A felhasználó azonosítás átmenetileg nem működik. Ha sokáig így lenne, légy szíves értesítsd a Wiki-gazdát!';
$lang['i_chooselang']          = 'Válassz nyelvet';
$lang['i_installer']           = 'DokuWiki Beállító Varázsló';
$lang['i_wikiname']            = 'A Wiki neve';
$lang['i_enableacl']           = 'Hozzáférési listák engedélyezése (ajánlott)';
$lang['i_superuser']           = 'Wiki-gazda';
$lang['i_problems']            = 'A Beállító Varázsló a következő problémák miatt megakadt. Nem tudjuk folytatni, amíg ezek nincsenek elhárítva!';
$lang['i_modified']            = 'Biztonsági okokból ez a Varázsló csak új és módosítatlan DokuWiki változaton működik.
Csomagold ki újra a fájlokat a letöltött csomagból, vagy nézd meg a teljes <a href="http://dokuwiki.org/install">Dokuwiki telepítési útmutatót</a>.';
$lang['i_funcna']              = 'A <code>%s</code> PHP funkció nem elérhető. Esetleg a tárhelyszolgáltató letiltotta biztonsági okok miatt?';
$lang['i_phpver']              = 'A PHP <code>%s</code> verziója alacsonyabb, mint ami szükséges lenne: <code>%s</code>. Frissítsd a PHP-det újabb verzióra!';
$lang['i_permfail']            = 'A DokiWiki nem tudja írni a <code>%s</code> könyvtárat. Be kell állítanod ehhez a könyvtárhoz a megfelelő jogosultságokat!';
$lang['i_confexists']          = '<code>%s</code> már létezik.';
$lang['i_writeerr']            = 'Nem tudom ezt létrehozni: <code>%s</code>. Ellenőrizd a könyvtár/fájl jogosultságokat, és hozd létre az állományt kézzel.';
$lang['i_badhash']             = 'A dokuwiki.php nem felismerhető vagy módosított (hash=<code>%s</code>)';
$lang['i_badval']              = '<code>%s</code> - nem helyes vagy üres érték';
$lang['i_success']             = 'A beállítás sikeresen befejeződött. Most már letörölhető az install.php fájl. Látogasd meg az <a href="doku.php?id=wiki:welcome">új DokuWikidet</a>!';
$lang['i_failure']             = 'Hiba lépett fel a konfigurációs állományok írásakor. Ki kell javítanod kézzel, mielőtt használni kezded az <a href="doku.php?id=wiki:welcome">új DokuWikidet</a>.';
$lang['i_policy']              = 'Kezdeti hozzáférési politika';
$lang['i_pol0']                = 'Nyitott Wiki (mindenki olvashatja, írhatja, és fájlokat tölthet fel)';
$lang['i_pol1']                = 'Publikus Wiki (mindenki olvashatja, de csak regisztrált felhasználók írhatják, és tölthetnek fel fájlokat)';
$lang['i_pol2']                = 'Zárt Wiki (csak regisztrált felhasználók olvashatják, írhatják és tölthetnek fel fájlokat)';
$lang['i_retry']               = 'Újra';
$lang['i_license']             = 'Kérlek válassz licenszt a feltöltött tartalomhoz:';
$lang['recent_global']         = 'Jelenleg csak a <b>%s</b> névtér friss változásai látszanak. Megtekinthetők <a href="%s">a teljes wiki friss változásai</a> is.';
$lang['years']                 = '%d évvel ezelőtt';
$lang['months']                = '%d hónappal ezelőtt';
$lang['weeks']                 = '%d héttel ezelőtt';
$lang['days']                  = '%d nappal ezelőtt';
$lang['hours']                 = '%d órával ezelőtt';
$lang['minutes']               = '%d perccel ezelőtt';
$lang['seconds']               = '%d másodperccel ezelőtt';
$lang['wordblock']             = 'A változásokat nem sikerült menteni, mert tiltott tartalom van benne (spam)';
